@@ -11,8 +11,8 @@ import (
 func implementedBackends(m *Machine) []backend {
 	return []backend{
 		newKvmBackend(m),
-		newUmlBackend(m),
 		newQemuBackend(m),
+		newUmlBackend(m),
 	}
 }
 
@@ -44,8 +44,8 @@ func newBackend(name string, m *Machine) (backend, error) {
 		for _, backend := range backends {
 			backendName := backend.Name()
 
-			/* The qemu backend is slow, don't allow users to auto-select it */
-			if backendName == "qemu" {
+			/* The user-mode-linux backend is flaky, don't allow users to auto-select it */
+			if backendName == "uml" {
 				continue
 			}
 
